% WDVV equation in 3 components: local Hamiltonian operators
% See Ferapontov, Galvao, Mokhov, Nutku, Comm. Math. Phys. 1995
% 2015-10-09

% Checking that
% 1 - the third-order operator aa2 fulfills [aa2,aa2]=0.
% 2 - the first-order operator aa1 fulfills [aa1,aa1]=0.
% 3 - the two operators are compatible, [aa1,aa2]=0.

load_package cde;

indep_var:={t,x}$
dep_var:={a,b,c}$
odd_var:={p,q,r}$
total_order:=10$
resname:="wdvv_biham1_res.red"$

% left-hand side of the differential equation
principal_der:={a_t,b_t,c_t}$
% right-hand side of the differential equation
de:={b_x,c_x,(2*b*b_x - a*c_x - a_x*c)}$

% same constructions for odd coordinates; here we do not need
% t-derivatives of odd variables
principal_odd:={p_t,q_t,r_t}$
de_odd:={0,0,0}$

% Calling cde's main routine
cde({indep_var,dep_var,odd_var,total_order},
   {principal_der,de,{},{}})$

% Number of components of the operators
ncomp:=length(dep_var)$

% Ist order operator
gu1:=mat(
  (-(3/2),(1/2)*a,b),
  ((1/2)*a,b,(3/2)*c),
  (b,(3/2)*c,2*(b**2 - a*c))
);
gamma_hi_con:=mat(
  (0,(1/2)*a_x,b_x),
  (0,(1/2)*b_x,c_x),
  (0,(1/2)*c_x,2*b*b_x - a_x*c - a*c_x)
  );

% The operator aa1 is the ansatz for the first homogeneous Hamiltonian operator
mk_cdiffop(aa1,1,{3},3)$
for all i,j,psi let aa1(i,j,psi)=
 gu1(i,j)*td(psi,x)+gamma_hi_con(i,j)*psi$

% IIIrd order operator

gu3:=mat(
  (0,0,1),(0,1, - a),(1, - a,2*b+a**2)
  );
c_hi_con:=mat(
  (0,0,0),
  (0,0, - a_x),
  (0,0,b_x + a*a_x)
  );

% The operator aa2 is the ansatz for the second hamiltonian operator aa
mk_cdiffop(aa2,1,{3},3)$
for all i,j,psi let aa2(i,j,psi) =
td(
  gu3(i,j)*td(psi,x,2)+c_hi_con(i,j)*td(psi,x)
    ,x
)$

% Now I start to compute Schouten brackets
conv_cdiff2superfun(aa1,sym1)$
conv_cdiff2superfun(aa2,sym2)$

conv_genfun2biv(sym1,biv1)$
conv_genfun2biv(sym2,biv2)$

iszero_schouten_bracket(biv1,biv1,sb11);
iszero_schouten_bracket(biv1,biv2,sb12);
iszero_schouten_bracket(biv2,biv2,sb22);

;end;

Local Variables:
mode:reduce
End:
